# comet_mpm

Python SDK for [Comet Model Production Monitoring](https://www.comet.com/site/products/model-production-monitoring/)

## Installation

```shell
pip install comet_mpm
```

To use these command-line functions, you'll need to have your Comet
API key set in one of the following two ways.

1. Environment variables (see below)
2. Directly as an argument to `comet_mpm.API(api_key="...")`

```
export COMET_API_KEY="YOUR-COMET-API-KEY"
```
